package com.jjt.biz.controller;

import com.jjt.biz.domain.AlarmRecord;
import com.jjt.biz.service.IAlarmRecordService;
import com.jjt.biz.vo.BizAccessVO;
import com.jjt.biz.vo.BizSortVO;
import com.jjt.biz.vo.BizTypeVO;
import com.jjt.biz.vo.LevelSortVO;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.page.TableDataInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 告警记录Controller
 *
 * @author jjt
 * @date 2024-08-08
 */
@Api(tags = "业务运行问题管理")
@RestController
@RequestMapping("/alarm/record")
public class AlarmRecordController extends BaseController {
    @Resource
    private IAlarmRecordService alarmRecordService;

    /**
     * 查询告警记录列表
     */
    @ApiOperation("查询告警记录列表")
    @PreAuthorize("@ss.hasPermi('alarm:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(AlarmRecord alarmRecord) {
        startPage();
        List<AlarmRecord> list = alarmRecordService.selectAlarmRecordList(alarmRecord);
        return getDataTable(list);
    }

    @ApiOperation("业务类型统计")
    @GetMapping("/list/bizType")
    public TableDataInfo listBizType(@ApiParam(value = "开始时间") Date start, @ApiParam(value = "结束时间") Date end) {
        List<BizTypeVO> list = new ArrayList();
        for (int i = 0; i < 10; i++) {
            list.add(new BizTypeVO(true));
        }
        return getDataTable(list);
    }

    @ApiOperation("应用组件统计")
    @GetMapping("/list/bizSort")
    public TableDataInfo listBizSort(@ApiParam(value = "分类") String bizType, @ApiParam(value = "开始时间") Date start, @ApiParam(value = "结束时间") Date end) {
        List<BizSortVO> list = new ArrayList();
        for (int i = 0; i < 10; i++) {
            list.add(new BizSortVO(true));
        }
        return getDataTable(list);
    }

    @ApiOperation("系统压力排名")
    @GetMapping("/list/bizAccess")
    public TableDataInfo listBizAccess(@ApiParam(value = "开始时间") Date start, @ApiParam(value = "结束时间") Date end) {
        List<BizAccessVO> list = new ArrayList();
        for (int i = 0; i < 10; i++) {
            list.add(new BizAccessVO(true));
        }
        return getDataTable(list);
    }

    @ApiOperation("等级级别排名")
    @GetMapping("/list/levelSort")
    public TableDataInfo listLevelSort(@ApiParam(value = "开始时间") Date start, @ApiParam(value = "结束时间") Date end) {
        List<LevelSortVO> list = new ArrayList();
        LevelSortVO ls1 = new LevelSortVO();
        ls1.setLevel("1");
        ls1.setNum(88L);
        LevelSortVO ls2 = new LevelSortVO();
        ls2.setLevel("2");
        ls1.setNum(15L);
        LevelSortVO ls3 = new LevelSortVO();
        ls3.setLevel("3");
        ls1.setNum(3L);
        return getDataTable(list);
    }

//    /**
//     * 导出告警记录列表
//     */
//    @ApiOperation("导出告警记录列表")
//    @PreAuthorize("@ss.hasPermi('alarm:record:export')")
//    @Log(title = "告警记录", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, AlarmRecord alarmRecord) {
//        List<AlarmRecord> list = alarmRecordService.selectAlarmRecordList(alarmRecord);
//        ExcelUtil<AlarmRecord> util = new ExcelUtil<AlarmRecord>(AlarmRecord.class);
//        util.exportExcel(response, list, "告警记录数据");
//    }
//
//    /**
//     * 获取告警记录详细信息
//     */
//    @ApiOperation("获取告警记录详细信息")
//    @PreAuthorize("@ss.hasPermi('alarm:record:query')")
//    @GetMapping(value = "/{alarmId}")
//    public AjaxResult getInfo(@PathVariable("alarmId") Long alarmId) {
//        return success(alarmRecordService.selectAlarmRecordByAlarmId(alarmId));
//    }
//
//    /**
//     * 新增告警记录
//     */
//    @ApiOperation("新增告警记录")
//    @PreAuthorize("@ss.hasPermi('alarm:record:add')")
//    @Log(title = "告警记录", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody AlarmRecord alarmRecord) {
//        return toAjax(alarmRecordService.insertAlarmRecord(alarmRecord));
//    }
//
//    /**
//     * 修改告警记录
//     */
//    @ApiOperation("修改告警记录")
//    @PreAuthorize("@ss.hasPermi('alarm:record:edit')")
//    @Log(title = "告警记录", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody AlarmRecord alarmRecord) {
//        return toAjax(alarmRecordService.updateAlarmRecord(alarmRecord));
//    }
//
//    /**
//     * 删除告警记录
//     */
//    @ApiOperation("删除告警记录")
//    @PreAuthorize("@ss.hasPermi('alarm:record:remove')")
//    @Log(title = "告警记录", businessType = BusinessType.DELETE)
//    @DeleteMapping("/{alarmIds}")
//    public AjaxResult remove(@PathVariable Long[] alarmIds) {
//        return toAjax(alarmRecordService.deleteAlarmRecordByAlarmIds(alarmIds));
//    }
}
